@@ -1,6 +1,6 @@
 #Plots the polygons in pal imported by get.paldata according
 #to the arcs in arc (value returned by get.arcdata)
-plotpal<-function(arc,pal, new=T)
+plotpal<-function(arc,pal, new=TRUE)
 {
 
 	#We only need the lists of arcs
@@ -18,7 +18,7 @@ plotpal<-function(arc,pal, new=T)
 		l<-length(pal[[i]][[1]])
 		for(j in 1:l)
 		{
-			arcs[abs(pal[[i]][[1]][j])]<-T	
+			arcs[abs(pal[[i]][[1]][j])]<-TRUE	
 		}
 	}
 
