@@ -1,3 +1,3 @@
 .First.lib <- function(lib, pkg) {
-	library.dynam("RInfo", pkg, lib)
+	library.dynam("RArcInfo", pkg, lib)
 }
